#
# spec file for package python-jupyter_contrib_nbextensions
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  test
Name:           python-jupyter_contrib_nbextensions
Version:        0.5.0
Release:        2.1
License:        BSD-3-Clause
Summary:        A collection of Jupyter nbextensions
Url:            https://github.com/ipython-contrib/jupyter_contrib_nbextensions
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/j/jupyter_contrib_nbextensions/jupyter_contrib_nbextensions-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-jupyter_nbconvert >= 4.2
BuildRequires:  python3-jupyter_notebook >= 4.0
%if %{with test}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module ipython_genutils}
BuildRequires:  %{python_module jupyter_contrib_core >= 0.3.3}
BuildRequires:  %{python_module jupyter_core}
BuildRequires:  %{python_module jupyter_highlight_selected_word >= 0.2}
BuildRequires:  %{python_module jupyter_latex_envs >= 1.3.8}
BuildRequires:  %{python_module jupyter_nbconvert >= 4.2}
BuildRequires:  %{python_module jupyter_nbextensions_configurator >= 0.2.8}
BuildRequires:  %{python_module jupyter_notebook >= 4.0}
BuildRequires:  %{python_module lxml >= 3.8.0}
BuildRequires:  %{python_module tornado}
BuildRequires:  %{python_module traitlets >= 4.1}
%endif
Requires:       python-PyYAML
Requires:       python-ipython_genutils
Requires:       python-jupyter_contrib_core >= 0.3.3
Requires:       python-jupyter_core
Requires:       python-jupyter_highlight_selected_word >= 0.2
Requires:       python-jupyter_latex_envs >= 1.3.8
Requires:       python-jupyter_nbconvert >= 4.2
Requires:       python-jupyter_nbextensions_configurator >= 0.2.8
Requires:       python-jupyter_notebook >= 4.0
Requires:       python-lxml >= 3.8.0
Requires:       python-tornado
Requires:       python-traitlets >= 4.1
Recommends:     python-jupyter_nbformat
Recommends:     python-requests
%ifpython3
Requires(post):   python-jupyter_nbconvert >= 4.2
Requires(post):   python-jupyter_notebook >= 4.0
Requires(preun):  python-jupyter_nbconvert >= 4.2
Requires(preun):  python-jupyter_notebook >= 4.0
%endif
%ifpython2
Requires:       python3-jupyter_contrib_nbextensions = %{version}
%endif
BuildArch:      noarch

%python_subpackages

%description
Contains a collection of extensions that add functionality to the Jupyter
notebook. These extensions are mostly written in Javascript, and are loaded
locally in the browser.

Please Note: Because a large number of extensions are provided, extensions
are not enabled automatically. Please use the nbextensions_configurator
extension to enable or disable them individually. It is pulled in as a
dependency of this package

%prep
%setup -q -n jupyter_contrib_nbextensions-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

PYTHONPATH=%{buildroot}%{python3_sitelib} %{buildroot}%{_bindir}/jupyter-contrib-nbextension install --nbextensions=%{buildroot}%{_datadir}/jupyter/nbextensions/ --only-files

# These are provided by separate packages
rm -r %{buildroot}%{_datadir}/jupyter/nbextensions/highlight_selected_word/
rm -r %{buildroot}%{_datadir}/jupyter/nbextensions/latex_envs/

%python_expand %fdupes %{buildroot}%{_datadir}/jupyter/nbextensions/

%if %{with test}
%check
%python_exec setup.py test
%endif

%post -n python3-jupyter_contrib_nbextensions
jupyter-contrib-nbextension install --only-config
exit 0

%preun -n python3-jupyter_contrib_nbextensions
if [ $1 == 0 ]   && [ -d %{python3_sitelib}/jupyter_contrib_nbextensions/ ] ; then
    jupyter-contrib-nbextension uninstall --only-config
fi
exit 0

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md
%license COPYING.rst
%python3_only %{_bindir}/jupyter-contrib-nbextension
%python3_only %{_datadir}/jupyter/nbextensions/*/
%{python_sitelib}/jupyter_contrib_nbextensions/
%{python_sitelib}/jupyter_contrib_nbextensions-%{version}-py*.egg-info


%changelog
* Wed May 30 2018 toddrme2178@gmail.com
- Don't include redundant and conflicting copies of
  highlight_selected_word and latex_envs extensions
* Thu May  3 2018 toddrme2178@gmail.com
- Use %%license tag
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to 0.5.0
  + `load_tex_macros` __new nbextension added!__
  + `cell_filter` __new nbextension added!__
  + `execution_dependencies` __new nbextension added!__
  + `isort` __new nbextension added!__
    First implementation based on code_prettify
  + require newer `jupyter_highlight_selected_word`
  + Fix for long button labels in `code_prettify` and variants
  + Bugfix for `collapsible_headings` key bindings conflict
  + `kernel_exec_on_cells`,
    make shift-click on button autoformat all cells
  + `scroll_down` ensure output will scroll down in new cells
  + `init_cell` Warning dialog now always relevant, fixes [#1223](https://github.com/ipython-contrib/jupyter_contrib_nbextensions/issues/1223). [#1226](https://github.com/ipython-contrib/jupyter_contrib_nbextensions/pull/1226) [@consideratio](https://github.com/consideratio)
  + `gist_it`, Fixed a minor spelling mistake in the documentation
  + `toc2`
  * fix css rule for overriding wrapper color
  * allow configurable basenumber
  * Initialize toc2 button after cfg is loaded / fix [#1249](https://github.com/ipython-contrib/jupyter_contrib_nbextensions/issues/1249).
  * use unaltered notebook metadata in template
  + `exercise` & `exercise2`, Reworking to fix
  + `snippets` use `base_url`
  + Add preprocessor to embed images into a notebook
  + `init_cell`
  * Warning dialog now always relevant, fixes [#1223](https://github.com/ipython-contrib/jupyter_contrib_nbextensions/issues/1223). [#1226](https://github.com/ipython-contrib/jupyter_contrib_nbextensions/pull/1226) [@consideratio](https://github.com/consideratio)
  + Add preprocessor to embed images into a notebook
  + Fixed conflicts in collapsible_headings if keys are rebound.
* Thu Feb 15 2018 toddrme2178@gmail.com
- Update to version 0.4.0
  + Repo-level stuff:
  * Require newer version of
  * Remove version-pinning from lxml dependency
  * Use `requirejs` vs. `require`, to align with notebook usage
  * `tests` specify exceptions (new flake8 moan)
  * move `js_highlight.py` into nbconvert_support, specify exception type
  * docs updates
  + New features and bugfixes:
  * `livemdpreview` __new nbextension added!__
  * `nbTranslate`
    > Typos + readability improvements
    > Fix typo and revise text for better readability
    > use traitlets > 4.1 tag API
  * `collapsible_headings`
    > indent heading collapse controls by level
    > patch TextCell.set_text to catch more changes
    > link complete font-awesome css from cdn, not just some fontfaces
  * `toc2`
    > Add a 'download as HTML with toc' for Jupyter >= 5.1
    > only set notebook dirty if metadata item changed
    > Bugfix undefined title_sidebar
    > move config into toc2.js
    > configurable titles; dialog-alterable metadata settings
    > remove deprecated st var from template
    > [toc2] link complete font-awesome css from cdn
  * `scroll_down` fix notebook `5.x` compatibility
  * `exercise,exercise2` use bootstrap hidden class
    rather than jquery show/hide, in order to play nicely with collapsible_headings.
  * `runtools` don't alter selection when running cells
  * `ExecuteTime` add preprocessor to execute notebook updating timing metadata
  * `snippets` Updated README
  * `code_prettify` Update `code_prettify.yaml`
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
